@@ -7,13 +7,28 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::TypeConstraints 2.135;
+package Config::Model::TypeConstraints 2.136;
 
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
+# used only for tests
+my $__test_home = '';
+sub _set_test_home { $__test_home = shift; }
+sub _get_test_home { return $__test_home ; }
+
 subtype 'Config::Model::TypeContraints::Path' => as 'Maybe[Path::Tiny]' ;
-coerce 'Config::Model::TypeContraints::Path' => from 'Str' => via sub { defined $_ ?  Path::Tiny::path($_) : undef ; } ;
+coerce 'Config::Model::TypeContraints::Path' => from 'Str' => via sub {
+    if (defined $_ and /^~/) {
+        # because of tests, we can't rely on Path::Tiny's tilde processing
+        # TODO: should this be my_config ? May be once this is done:
+        # https://github.com/perl5-utils/File-HomeDir/pull/5/files
+        # beware of compat and migration issues
+        my $home = $__test_home || File::HomeDir->my_home;
+        s/^~/$home/;
+    }
+    return defined $_ ?  Path::Tiny::path($_) : undef ;
+} ;
 
 1;
 
@@ -31,7 +46,7 @@ Config::Model::TypeConstraints - Mouse type constraints for Config::Model
 
 =head1 VERSION
 
-version 2.135
+version 2.136
 
 =head1 SYNOPSIS
 
